@@ -1,12 +1,12 @@
-"HSD.test" <-
+`HSD.test` <-
 function (y, trt, DFerror, MSerror, alpha=0.05, group=TRUE,main = NULL)
 {
     name.y <- paste(deparse(substitute(y)))
     name.t <- paste(deparse(substitute(trt)))
     junto <- subset(data.frame(y, trt), is.na(y) == FALSE)
-    means <- tapply.stat(junto[,2],junto[,1],stat="mean")
-    sds <-   tapply.stat(junto[,2],junto[,1],stat="sd")
-    nn <-   tapply.stat(junto[,2],junto[,1],stat="length")
+    means <- tapply.stat(junto[,1],junto[,2],stat="mean") # change
+    sds <-   tapply.stat(junto[,1],junto[,2],stat="sd") #change
+    nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
     means<-data.frame(means,std.err=sds[,2]/sqrt(nn[,2]),replication=nn[,2])
     names(means)[1:2]<-c(name.t,name.y)
 #   row.names(means)<-means[,1]
@@ -62,3 +62,4 @@ output<-data.frame(trt= means[,1],means= means[,2],M="",N=means[,4],std.err=mean
 }
 return(output)
 }
+
