@@ -68,7 +68,7 @@ a<-breaks[1]-ancho[1]/2
 b<-breaks[k+1]+ancho[k]/2
 relative<-round(counts/sum(counts),4)
 density <- relative/ancho
-histogram<-list(breaks=breaks,counts=counts,mids=mids,relative=relative,density=density)
+histogram<-structure(list(breaks=breaks,counts=counts,mids=mids,relative=relative,density=density),class="graph.freq")
 
 if(plot) {
 x <- c(a, b)
@@ -90,5 +90,5 @@ for (j in 1:k) {
 suppressWarnings(warning(rect(breaks[j], 0, breaks[j + 1], density[j], ...)))
 }}
 }
-    return(histogram)
+    invisible(histogram)
 }
